
import './class-component-hooks'

import Vue from 'vue'
import store from './store/store'
import App from './App.vue'
import router from './router/index'
import Vuetify from 'vuetify'
import Notifications from 'vue-notification'
import Clipboard from 'v-clipboard'
import * as Sentry from '@sentry/browser'
import * as Integrations from '@sentry/integrations'

import 'vuetify/dist/vuetify.min.css'
import 'highlight.js/styles/atom-one-light.css'

import '@/util/shortkeys'

Vue.use(Vuetify)

Vue.use(Clipboard)
Vue.use(Notifications)

const integrations = [
  new Integrations.Vue({Vue, attachProps: true, logErrors: true}),
  new Integrations.ExtraErrorData({depth: 10}),
  new Integrations.CaptureConsole({levels: ['warn', 'error']}),
  new Integrations.Debug()
]

if (process.env.NODE_ENV === 'test' || process.env.VUE_APP_CI === 'true') {
  Sentry.init({
    dsn: 'https://c86a983153da412b8aec8b8df9ce51ba@robin-in.space/2',
    integrations
  })
} else if (process.env.NODE_ENV === 'production') {
  Sentry.init({
    dsn: 'https://874b896335564d8c9c49137391f8e3f1@robin-in.space/3',
    integrations
  })
}

Vue.config.productionTip = false

const el = process.env.NODE_ENV === 'test' ? undefined : '#app'

export default new Vue({
  el: el,
  router: router,
  store,
  render: h => h(App)
}).$mount(el)
